@@ -1,4 +1,6 @@
 nmTest({
+  .nlmixr <- .nlmixr2 <- function(...) suppressMessages(nlmixr(...))
+
   test_that("eta fixed saem", {
     one.cmt <- function() {
       ini({
@@ -21,8 +23,8 @@ nmTest({
         linCmt() ~ add(add.sd)
       })
     }
-    
-    f <- nlmixr(one.cmt, nlmixr2data::theo_sd, "saem")
+
+    f <- .nlmixr(one.cmt, nlmixr2data::theo_sd, "saem")
     expect_equal(names(f$eta),
                  c("ID", "eta.ka", "eta.cl", "eta.v"))
     expect_equal(names(f$parHist),
