@@ -1,6 +1,63 @@
 nmTest({
   .nlmixr <- function(...) suppressWarnings(suppressMessages(nlmixr(...)))
 
+  test_that("nlme will pick up interpolation", {
+
+    one.compartment <- function() {
+      ini({
+        tka <- 0.45 # Log Ka
+        tcl <- 1 # Log Cl
+        tv <- 3.45    # Log V
+        eta.ka ~ 0.6
+        eta.cl ~ 0.3
+        eta.v ~ 0.1
+        add.sd <- 0.7
+      })
+      model({
+        ka <- exp(tka + eta.ka)
+        cl <- exp(tcl + eta.cl) + wt
+        v <- exp(tv + eta.v)
+        d/dt(depot) = -ka * depot
+        d/dt(center) = ka * depot - cl / v * center
+        cp = center / v
+        cp ~ add(add.sd)
+      })
+    }
+
+
+    f <- one.compartment()
+
+    expect_false(grepl("linear\\(wt\\)", rxode2::rxNorm(f$nlmRxModel$predOnly)))
+
+    one.compartment <- function() {
+      ini({
+        tka <- 0.45 # Log Ka
+        tcl <- 1 # Log Cl
+        tv <- 3.45    # Log V
+        eta.ka ~ 0.6
+        eta.cl ~ 0.3
+        eta.v ~ 0.1
+        add.sd <- 0.7
+      })
+      model({
+        linear(wt)
+        ka <- exp(tka + eta.ka)
+        cl <- exp(tcl + eta.cl) + wt
+        v <- exp(tv + eta.v)
+        d/dt(depot) = -ka * depot
+        d/dt(center) = ka * depot - cl / v * center
+        cp = center / v
+        cp ~ add(add.sd)
+      })
+    }
+
+
+    f <- one.compartment()
+
+    expect_true(grepl("linear\\(wt\\)", rxode2::rxNorm(f$nlmRxModel$predOnly)))
+
+  })
+
   test_that("nlme one compartment theo_sd", {
 
     one.compartment <- function() {
@@ -224,7 +281,7 @@ nmTest({
       })
     }
 
-    skip_if_not(rxode2parse::.linCmtSens())
+    skip_if_not(rxode2::.linCmtSensB())
 
     fit_nlme <- .nlmixr(one.cmt.all.mu.ref, theo_sd, est="nlme", control=nlmeControl(verbose=FALSE, returnObject=TRUE))
     expect_true(!all(ranef(fit_nlme)[[1]] == 0))
